library(tidyverse)

## load data
matched <- readRDS(file = "df-long.RDS")

## boxplot (FIGURE 2)
library(ggplot2)

matched <-  matched %>%
    mutate(task2 = paste(task, gramm, sep = "_"))

matched$task2 <- recode(matched$task2, PST_ps = "PST")

boxdata <- matched %>%
    group_by(task2, participant) %>%
    summarise(accuracy = sum(response)) %>%
    as.data.frame()

partid <- matched %>%
    group_by(participant) %>%
    slice(1) %>%
    as.data.frame() %>%
    select(group, participant)

boxdata <- left_join(boxdata, partid, "participant") %>%
    select(accuracy, task2, group) %>%
    rename(task = task2)

boxdatapst <- boxdata[boxdata$task=="PST", ]
boxdatagjt <- boxdata[boxdata$task!="PST", ]

boxdatapst <- boxdatapst %>%
    mutate(accuracy2 = accuracy/80)

boxdatagjt <- boxdatagjt %>%
    mutate(accuracy2 = accuracy/40)

boxdata <- rbind(boxdatapst, boxdatagjt)

boxdata$task <- as.factor(boxdata$task)
levels(boxdata$task)
boxdata$task = fct_relevel(boxdata$task, c("PST",
                                           "wGJT_G",
                                           "sGJT_G",
                                           "wGJT_U",
                                           "sGJT_U"))

boxdata$group = fct_relevel(boxdata$group, c("classroom", "immersion", "native"))

boxplot <- ggplot(boxdata, aes(x=group,
                              y=accuracy2,
                               fill=group)) +
    geom_boxplot(outlier.shape = NA) +
    geom_jitter(size=0.7, position=position_jitter(0.1)) +
    stat_summary(fun.y = mean, geom = "point", shape=23, size=3, fill = "#ffffcc") +
    scale_fill_manual(values = c("#39ac73", "#ffc34d", "#336699")) +
    ## scale_fill_brewer(palette="Spectral") +
    facet_grid(cols = vars(task)) +
    ylab("accuracy") +
    ggtitle("Response accuracy across groups and tasks") +
    theme(axis.text.x = element_text(angle = 90, hjust = 1, vjust = 0.5),
          axis.text=element_text(size=12),
          axis.title=element_text(size=14),
          legend.position = "none")

boxplot

ggsave(filename = "FIGURE2.tiff",
       width =25, height = 20, unit = "cm",
       plot = boxplot)


## summary table gr/ugr (TABLE 3)

table <- boxdata %>%
    group_by(task, group) %>%
    summarise(mean_resp = round(mean(accuracy2), 2),
              sd_resp = round(sd(accuracy2), 2))

table

## summary table wGJT/sGJT (TABLE 3)

tabledata <- matched %>%
    group_by(task, participant) %>%
    summarise(accuracy = sum(response)) %>%
    as.data.frame()

partid <- matched %>%
    group_by(participant) %>%
    slice(1) %>%
    as.data.frame() %>%
    select(group, participant)

tabledata <- left_join(tabledata, partid, "participant") %>%
    select(accuracy, task, group) %>%
    mutate(accuracy2 = accuracy/80) %>% 
    group_by(task, group) %>%
    summarise(mean_resp = round(mean(accuracy2), 2),
              sd_resp = round(sd(accuracy2), 2))

tabledata


## model fit
## training the model may take several hours

library(brms)

fit <- brm(response ~ task + group +
              task:group + 
              task:group:taskident:gramm +
              (1 | item) +
              (1 | task:participant),
          data = matched,
          family = "bernoulli",
          prior = c(prior(normal(0, 4), class = b),
                    prior(normal(0, 4), class = Intercept)),
          control = list(#adapt_delta = 0.99,
              max_treedepth = 15),
          warmup = 500,
          iter = 4000,
          chains = 4,
          inits= 0,
          cores=4,
          seed = 42)


## model results, convergence, fit

fit
plot(fit)
bayes_R2(fit)


## confusion matrix
library(caret)

preds <- predict(fit)
preds <- as.data.frame(preds)
preds <- mutate(preds, est = if_else(Estimate<=0.5, 0, 1))
preds$est <- as.factor(preds$est)

matched$response <- as.factor(matched$response)

confusionMatrix(preds$est, matched$response)


## prepare conditions and predictions for FIGURE 3

conds_GJT <- make_conditions(fit, c("group", "task", "gramm")) %>%
    mutate(taskident = 1)

preds_GJT <- fitted(fit, resp = "response",
                   newdata = conds_GJT,
                   re_formula = NA)

conds_PST <- make_conditions(fit, c("group", "task", "gramm")) %>%
    mutate(taskident = 0)

preds_PST <- fitted(fit, resp = "response",
                   newdata = conds_PST,
                   re_formula = NA)


## make conditional effect df for FIGURE 3

ce_GJT <- cbind(conds_GJT, preds_GJT) %>%
    filter(task != "PST",
           gramm != "ps")

ce_PST <- cbind(conds_PST, preds_PST) %>%
    filter(task == "PST",
           gramm == "ps")

ce <- rbind(ce_GJT, ce_PST) %>%
    mutate(task = paste(task, gramm, sep = "_")) %>% 
    arrange(task, group)

ce$task <- recode(ce$task, PST_ps = "PST")

ce$task = fct_relevel(ce$task, c("PST",
                                 "wGJT_G",
                                 "sGJT_G",
                                 "wGJT_U",
                                 "sGJT_U"))

levels(ce$group)
ce$group = fct_relevel(ce$group, c("classroom", "immersion", "native"))


## plot conditional effects (FIGURE 3)

ceplot <- ggplot(ce, aes(x = task, y = Estimate, shape = group, color=group)) +
    geom_errorbar(aes(x=task, ymax=Q97.5, ymin=Q2.5), position=position_dodge(width=0.3), width=0.3) +
    geom_point(, position=position_dodge(width=0.3), size = 2) +
    scale_color_manual(values = c("#39ac73", "#e69900", "#336699")) +
    ylim(0.7,1) +
    ylab("estimated proportion of correct answer")+
    xlab("group") +
    theme(legend.position = "bottom")

ceplot

ggsave(filename = "FIGURE3.tiff",
       width =12, height = 15, unit = "cm",
       plot = ceplot)


## conditional effects for TABLE 3

ce$Estimate <- round(ce$Estimate, 2)
ce$Q2.5 <- round(ce$Q2.5, 2)
ce$Q97.5 <- round(ce$Q97.5, 2)

ce



## ranges for FIGURE 4

df <- data.frame(group = c("Chinese & Korean (Johnson & Newport)",
                          "Spanish (Birdsong & Mollis)",
                          "Russian (DeKeyser et al. 2010)",
                          "Hungarian (DeKeyser 2000)",
                          "Immersion learners (this study)",
                          "Classroom learners (this study)",
                          "Natives (Johnson & Newport)" ,
                          "Natives (this study, matched sample)",
                          "Natives (this study, full sample)",
                          "Natives (this study, full sample), normal range"),
                mean = c(76,86,76,74,82,79,97,94,94,94),
                min = c(59,59,57,55,47,50,96,81,54,85),
                max = c(92,98,94,95,96,99,100,100,100,100),
                native = c(rep("non-natives", 6), rep("natives",4))
                )

df$group <- fct_relevel(df$group, c("Natives (this study, full sample), normal range",
                                   "Natives (this study, full sample)",
                                   "Natives (this study, matched sample)",
                                   "Natives (Johnson & Newport)",
                                   "Classroom learners (this study)",
                                   "Immersion learners (this study)",
                                   "Hungarian (DeKeyser 2000)",
                                   "Russian (DeKeyser et al. 2010)",
                                   "Spanish (Birdsong & Mollis)",
                                   "Chinese & Korean (Johnson & Newport)" 
                                   ))



a <- c("bold", "bold", "bold", "plain", "bold", "bold", "plain", "plain", "plain", "plain")

ranges <- ggplot(df, aes(x=(mean), y=group))+
    geom_segment(aes(x = min, y = group, xend = max, yend = group, color = native), size = 5, alpha=0.6) +
    scale_colour_manual(values= c("darkred", "lightskyblue")) +
    geom_point(size = 2) +
    xlim(0,100) +
    xlab("means with ranges in %") + 
    theme(axis.text.y = element_text(face = a, size = 11),
          legend.position = "bottom",
          legend.title = element_blank()) 

ranges

ggsave(filename = "FIGURE4.tiff",
       width = 20, height = 13, unit = "cm",
       plot = ranges)









